{% extends "base.html" %} {% block body %}
<div class="wrapper min-vh-100">
    <aside class="navbar navbar-vertical navbar-expand-lg navbar-dark">
        <div class="container-fluid">
            {% if request.app.logo_url %}
            <h1 class="navbar-brand navbar-brand-autodark">
                <a href="{{ request.app.admin_path }}" style="font-size: 1.75rem;">
                    FastTower
                </a>
            </h1>
            {% endif %}

            <div class="collapse navbar-collapse" id="navbar-menu">
                <ul class="navbar-nav pt-lg-3">
                    {% for resource in resources %} {% if resource.type == 'link' %}
                    {% include 'components/link.html' %} {% elif resource.type == 'model' %}
                    {% include 'components/model.html' %} {% elif resource.type == 'dropdown' %} {% include
                    'components/dropdown.html' %} {% endif %} {% endfor %}
                </ul>
            </div>
        </div>
    </aside>
    <div class="page-wrapper min-vh-100">
        <header
                class="navbar navbar-expand-md navbar-light d-none d-lg-flex d-print-none"
        >
            <div class="container-fluid">
<!--                <button-->
<!--                        class="navbar-toggler"-->
<!--                        type="button"-->
<!--                        data-bs-toggle="collapse"-->
<!--                        data-bs-target="#navbar-menu">-->
<!--                    <span class="navbar-toggler-icon"></span>-->
<!--                </button>-->
                <div class="navbar-nav flex-row order-md-last">
                    {% if request.app.language_switch %}
                    {% include "components/language.html" %}
                    {% endif %}
                    {% if request.app.login_provider %}
                    {% include "providers/login/avatar.html" %}
                    {% endif %}
                </div>
                <div></div>
            </div>
        </header>
        <div class="container-fluid">
            <div class="page-header d-print-none">
                {% block page_header %}
                <div class="row align-items-center">
                    <div class="col">
                        <div class="page-pretitle">{{ page_pre_title or '' }}</div>
                        <h2 class="page-title">{{ page_title or '' }}</h2>
                    </div>
                </div>
                {% block page_title_actions %} {% endblock %} {% endblock %}
            </div>
        </div>
        <div class="page-body flex-grow-1">
            <div class="container-fluid">
                <div class="row row-deck row-cards">
                    {% block page_body %} {% endblock %}
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}